"""

https://drive.google.com/drive/folders/1EB0wnC4k2TNQNbXv5rqQKcmNYd2WepgB?usp=sharing

Здесь все файлы

Чтобы найти теорию.
пишем from tprob import q
Дальше 
q.show_q1_1() - задания q1 первая половина
q.show_q1_2() - задания q1 вторая половина
q.show_q2_1() - задания q2 первая половина
q.show_q2_2() - задания q2 вторая половина
q.show_q3_1() - задания q1 первая половина

q.show_google() - откроет гугл

q.show_questions_1() - список вопросов часть 1
q.show_questions_2() - список вопросов часть 1

Чтобы посмотреть решения практики
from tprob import prac_tasks
help(prac_tasks)
ищем задание
копируем решение и меняем параметры

для задания с датасетом
from tprob import zadanie_6
help(zadanie_6)

Там должно быть разделение на ячейки. Каждая ячейка обернута в ##

Если нужны лекции
from tprob import teor
teor.get_lecture()
"""